# Pivimage

`PIVimage` is a small library assisting with reading PIV images. It provides specific utilities to handle PIV images and 
to perform certain operations on them, which are useful in the pre-processing stage of PIV analysis.

Available operations are ...
- rotating images
- interfacing with double frame images in one or two files
- plotting

More features will be added in the future.

## Installation
```bash
pip install pivimage
```

## Examples

